/**
 * This spec is testing the Angular Dev app.
 *
 * @NOTE you need to have running dev app
 *
 * Go to `packages/angular` and run `yarn run serve`
 *
 * After that you may run only this spec.
 *
 * vdiff --specs="./specs/angular.vspec.js"
 */
const VisualDiffContext = require('../dist/index').VisualDiffContext;

const CLARITY_ANGULAR_DEV = process.env.CLARITY_ANGULAR_DEV || 'http://localhost:4200';
const UPDATE_SNAPSHOTS = process.env.UPDATE_SNAPSHOTS || false;

const pagesList = [
  'accordion',
  'alert/static/styles',
  'alert/static/sizes',
  'alert/static/cards',
  'alert/static/modals',
  'alert/static/content-area',
  'alert/static/app-level',
  'alert/angular/not-closable',
  'alert/angular/small',
  'alert/angular/close-events',
  'alert/angular/success',
  'alert/angular/app-level',
  'alert/angular/app-level-alerts',
  'badges/color-options',
  'badges/status',
  'button-group/static/basic-structure',
  'button-group/static/types',
  'button-group/static/directions',
  'button-group/static/icons',
  'button-group/static/icon-button-group',
  'button-group/static/icons-with-text',
  'button-group/static/checkboxes',
  'button-group/static/radios',
  'button-group/static/cards',
  'button-group/angular/basic-structure',
  'button-group/angular/directions',
  'button-group/angular/icon-button',
  'button-group/angular/icon-button',
  'button-group/angular/loading-button',
  'button-group/angular/hide-overflow',
  'button-group/angular/mixed-buttons',
  'button-group/angular/move-button-in-menu',
  'button-group/angular/move-multiple-buttons-in-menu',
  'buttons/real-button',
  'buttons/primary-button',
  'buttons/secondary-button',
  'buttons/tertiary-button',
  'buttons/inverse-button',
  'buttons/button-states',
  'buttons/button-loading',
  'buttons/button-sizes',
  'buttons/icons',
  'buttons/icon-buttons',
  'buttons/buttons-test',
  'card/grid',
  'card/clickable',
  'card/dropdown',
  'card/images',
  'card/layout',
  'card/masonry',
  'card/media-block',
  'card/list-group',
  'card/old',
  'checkboxes',
  'color/color-palette',
  'combobox',
  'custom-props',
  'datagrid/structure',
  'datagrid/kitchen-sicken',
  'datagrid/custom-rendering',
  'datagrid/smart-iterator',
  'datagrid/binding-properties',
  'datagrid/sorting',
  'datagrid/filtering',
  'datagrid/string-filtering',
  'datagrid/pagination',
  'datagrid/pagination-scrolling',
  'datagrid/pagination-conditional',
  'datagrid/selection',
  'datagrid/selection-single',
  'datagrid/selection-row-mode',
  'datagrid/preserve-selection',
  'datagrid/server-driven',
  'datagrid/placeholder',
  'datagrid/scrolling',
  'datagrid/column-sizing',
  'datagrid/compact',
  'datagrid/detail',
  'datagrid/expandable-rows',
  'datagrid/full',
  'datagrid/test-cases',
  'datagrid/test-cases-async',
  'datagrid/hide-show',
  'datagrid/responsive-footer',
  'datagrid/conditional-selection',
  'datalist',
  'drag-and-drop/draggable',
  'drag-and-drop/draggable-handle',
  'drag-and-drop/custom-ghost',
  'drag-and-drop/custom-ghost-and-handle',
  'drag-and-drop/droppable',
  'drag-and-drop/drop-tolerance',
  'drag-and-drop/groupng',
  'datepicker/ng-model-auto-wrapped',
  'datepicker/ng-model-wrapper-present',
  'datepicker/datepicker-date-input',
  'datepicker/datepicker-date-input-wrapper-presentit',
  'datepicker/disabled',
  'datepicker/datepicker-min-max',
  'dropdown/default',
  'dropdown/positioning',
  'dropdown/icon-toggle',
  'dropdown/buttonlink-toggle',
  'dropdown/angular-positioning',
  'dropdown/angular-nested',
  'dropdown/multi-click',
  'dropdown/dropdown-header',
  'forms/layout-vertical',
  'forms/layout-horizontal',
  'forms/layout-compact',
  'forms/layout-vertical-grid',
  'forms/layout-horizontal-grid',
  'forms/layout-compact-grid',
  'forms/layout-vertical-angular',
  'forms/layout-horizontal-angular',
  'forms/layout-compact-angular',
  'forms/layout-horizontal-angular-grid',
  'forms/layout-compact-angular-grid',
  'forms/input-group',
  'forms/layout-modal',
  'forms/text',
  'forms/checkbox',
  'forms/radio',
  'forms/file',
  'forms/textarea',
  'forms/select',
  'forms/template-driven',
  'forms/reactive',
  'forms/reset',
  'forms/a11y',
  'forms/generic-container',
  'forms/validation',
  'grid/grid-columns',
  'grid/grid-columns-stacking',
  'grid/grid-columns-offsetting',
  'grid/grid-column-wrapping',
  'grid/grid-equal-widths',
  'grid/grid-one-col-width',
  'grid/grid-variable-width-content',
  'grid/grid-equal-width-multi-row',
  'iconography/selection',
  'iconography/color-options',
  'iconography/inverse-color',
  'iconography/size',
  'iconography/orientation',
  'iconography/variants',
  'iconography/view-box-test',
  'images',
  'input',
  '🇫🇷♿',
  'labels/default',
  'labels/color-options',
  'labels/clickable',
  'labels/status',
  'labels/with-badges',
  'layout/layout-all',
  'layout/layout-no-subnav',
  'layout/layout-no-sidenav',
  'layout/layout-only-header',
  'layout/layout-subnav-primary',
  'layout/layout-sidenav-primary',
  'layout/layout-additional-sections',
  'lists/lists-ul',
  'lists/lists-unstyled',
  'lists/lists-ol',
  'lists/lists-mixed',
  'lists/lists-compact',
  'lists/lists-in-cards',
  'login',
  'modal/static',
  'modal/old-close-button',
  'modal/sizes',
  'modal/max-height',
  'modal/backdrop',
  'modal/animation',
  'modal/dynamic-show',
  'modal/dynamic-sizing',
  'modal/static-backdrop',
  'modal/not-closable',
  'modal/focus-trap',
  'modal/modal-form',
  'navigation/headers',
  'navigation/nav-tabs',
  'navigation/sidenav',
  'navigation/subnav',
  'navigation/responsive-nav1',
  'navigation/responsive-nav2',
  'navigation/headers/header-types',
  'navigation/headers/header-colors',
  'navigation/headers/header-types-old',
  'password',
  'progress-bars/progress-bar-examples',
  'progress-bars/progress-bar-colors',
  'progress-bars/progress-bar-animations',
  'progress-bars/progress-bar-cards',
  'progress-bars/progress-bar-sidenav',
  'progress-bars/progress-bar-loop',
  'progress-bars/progress-bar-static',
  'progress-bars/progress-bar-static-cards',
  'progress-bars/progress-bar-inline',
  'progress-bars/progress-bar-inline-cards',
  'progress-bars/progress-bar-component',
  'radios',
  'ranges',
  'selects',
  'signposts',
  'spinners',
  'stack-view/static',
  'stack-view/angular-basic',
  'stack-view/angular-modal-edit',
  'stack-view/angular-lazyload',
  'stepper',
  'tables/tables-basic',
  'tables/tables-leftcell',
  'tables/tables-multiline',
  'tables/tables-noborder',
  'tables/tables-compact',
  'tables/tables-compact-noborder',
  'tables/tables-vertical',
  'tables/tables-vertical-noborder-compact',
  'tables/tables-width',
  'tabs/static',
  'tabs/angular',
  'textarea',
  'tree-view/eager-declarative',
  'tree-view/eager-recursive',
  'tree-view/lazy-declarative',
  'tree-view/lazy-recursive',
  'tree-view/nodes-with-icons',
  'tree-view/routing',
  'tree-view/pre-selection',
  'timeline/static',
  'timeline/angular',
  'toggles',
  'tooltips/sizes',
  'tooltips/directions',
  'tooltips/angular',
  'typography/typography-font-weight',
  'typography/typography-headers',
  'typography/typography-text',
  'typography/typography-links',
  'typography/typography-font-char-test',
  'typography/typography-line-height',
  'typography/typography-font-autopsy',
  'vertical-nav/static',
  'vertical-nav/basic',
  'vertical-nav/header-and-divider',
  'vertical-nav/collapsible',
  'vertical-nav/icons',
  'vertical-nav/nested-menus',
  'vertical-nav/nested-icon-menus',
  'vertical-nav/partial-nested-menus',
  'vertical-nav/partial-nested-icon-menus',
  'vertical-nav/routing',
  'vertical-nav/accessibility',
  'vertical-nav/without-expanded-directive',
  'vertical-nav/unstructured-routes',
  'vertical-nav/highlights',
  'vertical-nav/all',
  'wizard/basic',
  'wizard/skip-page',
  'wizard/form-validation',
  'wizard/async-validation',
  'wizard/not-closable',
  'wizard/custom-buttons',
  'wizard/jump-to',
  'wizard/step-error',
  'wizard/reset',
  'wizard/header-actions',
  'wizard/alt-cancel',
  'wizard/alt-next',
  'wizard/force-forward',
  'wizard/stop-navigation',
];

// cache size.
const pageListLength = pagesList.length;

describe(`Clarity Angular Development ${CLARITY_ANGULAR_DEV}`, () => {
  let browser, VisualDiff;

  beforeAll(async () => {
    VisualDiff = new VisualDiffContext('angular.vspec.js', { updateSnapshots: UPDATE_SNAPSHOTS });
    await VisualDiff.prepare();
    browser = await VisualDiff.createBrowser();
  });

  afterAll(async () => {
    browser.close();
  });

  for (let i = 0; i < pageListLength; i++) {
    const target = pagesList[i];

    it(target, async () => {
      await VisualDiff.visitAndCompareWithBase(
        `${CLARITY_ANGULAR_DEV}/${target}`,
        'main.content-area',
        target,
        browser
      );
    });
  }
});
